==> constructorio-ui-quizzes-1.2.3.tgz: package/lib/mjs/components/OpenTextTypeQuestion/OpenTextTypeQuestion.js <==
import React, { useContext, useEffect, useState } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import { renderImages } from '../../utils';
import QuizContext from '../CioQuiz/context';
import { QuestionTypes } from '../CioQuiz/actions';
import ControlBar from '../ControlBar/ControlBar';
function OpenTextQuestion(props) {
    const { initialValue = '', onChangeHandler: userDefinedHandler = null } = props;
    const { questionResponse, quizBackHandler, quizNextHandler, isFirstQuestion, state } = useContext(QuizContext);
    const [openTextInput, setOpenTextInput] = useState(initialValue);
    let question;
    if (questionResponse) {
        question = questionResponse.next_question;
    }
    const onChangeHandler = (e) => {
        setOpenTextInput(e.target.value);
        if (userDefinedHandler) {
            userDefinedHandler(e);
        }
    };
    const onNextClick = () => {
        if (quizNextHandler && openTextInput && questionResponse) {
            quizNextHandler({
                type: QuestionTypes.OpenText,
                payload: {
                    questionId: questionResponse.next_question.id,
                    input: openTextInput,
                    isLastQuestion: questionResponse.is_last_question,
                },
            });
        }
    };
    const onKeyDownHandler = (e) => {
        const { key } = e;
        if (key === 'Enter') {
            onNextClick();
        }
    };
    useEffect(() => {
        if (questionResponse) {
            const openTextAnswer = state?.answerInputs?.[questionResponse?.next_question.id] || initialValue;
            setOpenTextInput(openTextAnswer);
        }
    }, [questionResponse, state, initialValue]);
    if (question) {
        const hasImage = question?.images?.primary_url;
        return (React.createElement("div", { className: `
          cio-container${hasImage ? '--with-image' : ''}
          cio-open-text-question-container${hasImage ? '--with-image' : ''}
        ` },
            hasImage ? renderImages(question.images, 'cio-question-image-container') : '',
            React.createElement("div", { className: 'cio-question-content' },
                React.createElement(QuestionTitle, { title: question.title }),
                React.createElement(QuestionDescription, { description: question.description }),
                React.createElement("input", { className: 'cio-question-input-text', placeholder: question.input_placeholder || 'Answer here...', value: openTextInput, onChange: onChangeHandler, onKeyDown: onKeyDownHandler }),
                React.createElement(ControlBar, { nextButtonHandler: onNextClick, isNextButtonDisabled: !openTextInput, backButtonHandler: quizBackHandler, showBackButton: !isFirstQuestion, ctaButtonText: question?.cta_text }))));
    }
    return null;
}
export default OpenTextQuestion;

==> constructorio-ui-quizzes-1.3.1.tgz: package/lib/mjs/components/OpenTextTypeQuestion/OpenTextTypeQuestion.js <==
import React, { useContext, useEffect, useState } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import { renderImages } from '../../utils';
import QuizContext from '../CioQuiz/context';
import ControlBar from '../ControlBar/ControlBar';
function OpenTextQuestion(props) {
    const { initialValue = '', onChangeHandler: userDefinedHandler = null } = props;
    const { state, previousQuestion, nextQuestion } = useContext(QuizContext);
    const [openTextInput, setOpenTextInput] = useState(initialValue);
    let question;
    if (state?.quiz.currentQuestion) {
        question = state?.quiz.currentQuestion.next_question;
    }
    const onChangeHandler = (e) => {
        setOpenTextInput(e.target.value);
        if (userDefinedHandler) {
            userDefinedHandler(e);
        }
    };
    const onNextClick = () => {
        if (nextQuestion && openTextInput) {
            nextQuestion(openTextInput);
        }
    };
    const onKeyDownHandler = (e) => {
        const { key } = e;
        if (key === 'Enter') {
            onNextClick();
        }
    };
    useEffect(() => {
        if (state?.quiz.currentQuestion) {
            const questionId = state?.quiz.currentQuestion?.next_question.id;
            const currentAnswer = state.answers.inputs?.[questionId];
            const openTextAnswer = currentAnswer || initialValue;
            setOpenTextInput(openTextAnswer);
        }
    }, [state, initialValue]);
    if (question) {
        const hasImage = question?.images?.primary_url;
        return (React.createElement("div", { className: `
          cio-container${hasImage ? '--with-image' : ''}
          cio-open-text-question-container${hasImage ? '--with-image' : ''}
        ` },
            hasImage ? renderImages(question.images, 'cio-question-image-container') : '',
            React.createElement("div", { className: 'cio-question-content' },
                React.createElement(QuestionTitle, { title: question.title }),
                React.createElement(QuestionDescription, { description: question.description }),
                React.createElement("input", { className: 'cio-question-input-text', placeholder: question.input_placeholder || 'Answer here...', value: openTextInput, onChange: onChangeHandler, onKeyDown: onKeyDownHandler }),
                React.createElement(ControlBar, { nextButtonHandler: onNextClick, isNextButtonDisabled: !openTextInput, backButtonHandler: previousQuestion, showBackButton: !state?.quiz.isFirstQuestion, ctaButtonText: question?.cta_text }))));
    }
    return null;
}
export default OpenTextQuestion;
